# Aicage custom base-image: `debian-mirror` (Debian)

This is a sample custom base-images for `aicage`.

It shows a reduced Dockerfile installing just the basic packages on top of an unofficial/mirrored Debian image.

> - `aicage` already provides images based on the [official Debian images(https://hub.docker.com/_/debian) with a larger
stack of tools. This is a sample on how to configure your own.
> - For a custom base-image with the full stack of tools see [../php](../php).

About:

- Image homepage: [https://github.com/rblaine95/dockerhub-mirror](https://github.com/rblaine95/dockerhub-mirror)
